@@ -1,5 +1,6 @@
-#[derive(Debug)]
+#[derive(Debug, PartialEq)]
 pub enum DeckError {
+    DuplicateCard,
     InvalidIndex,
     Incomplete,
     PilePackMismatch,
